@@ -1,57 +1,20 @@
-/* This file is part of the KDE libraries
+/*
+    This file is part of the KDE libraries
 
-   Copyright (c) 2000,2001 Dawit Alemayehu <adawit@kde.org>
-   Copyright (c) 2000,2001 Carsten Pfeiffer <pfeiffer@kde.org>
-   Copyright (c) 2000 Stefan Schimanski <1Stein@gmx.de>
+    SPDX-FileCopyrightText: 2000, 2001 Dawit Alemayehu <adawit@kde.org>
+    SPDX-FileCopyrightText: 2000, 2001 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2000 Stefan Schimanski <1Stein@gmx.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Lesser General Public
-   License (LGPL) as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Lesser General Public License for more details.
-
-   You should have received a copy of the GNU Lesser General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "kcombobox.h"
+#include "kcombobox_p.h"
 
+#include <kcompletion_debug.h>
 #include <kcompletionbox.h>
-#include <klineedit.h>
 
 #include <QUrl>
-#include <QPointer>
-#include <QMenu>
-
-class KComboBoxPrivate
-{
-public:
-    KComboBoxPrivate(KComboBox *parent)
-        : q_ptr(parent)
-    {
-    }
-    ~KComboBoxPrivate()
-    {
-    }
-
-    /**
-     * Initializes the variables upon construction.
-     */
-    void init();
-
-    void _k_lineEditDeleted();
-
-    KLineEdit *klineEdit = nullptr;
-    bool trapReturnKey = false;
-    KComboBox * const q_ptr;
-    Q_DECLARE_PUBLIC(KComboBox)
-};
 
 void KComboBoxPrivate::init()
 {
@@ -72,21 +35,23 @@ void KComboBoxPrivate::_k_lineEditDeleted()
     }
 }
 
-
 KComboBox::KComboBox(QWidget *parent)
-    : QComboBox(parent),
-      d_ptr(new KComboBoxPrivate(this))
+    : KComboBox(*new KComboBoxPrivate(this), parent)
+{
+}
+
+KComboBox::KComboBox(KComboBoxPrivate &dd, QWidget *parent)
+    : QComboBox(parent)
+    , d_ptr(&dd)
 {
     Q_D(KComboBox);
+
     d->init();
 }
 
 KComboBox::KComboBox(bool rw, QWidget *parent)
-    : QComboBox(parent),
-      d_ptr(new KComboBoxPrivate(this))
+    : KComboBox(*new KComboBoxPrivate(this), parent)
 {
-    Q_D(KComboBox);
-    d->init();
     setEditable(rw);
 }
 
@@ -207,7 +172,7 @@ void KComboBox::setTrapReturnKey(bool trap)
     if (d->klineEdit) {
         d->klineEdit->setTrapReturnKey(trap);
     } else {
-        qWarning("KComboBox::setTrapReturnKey not supported with a non-KLineEdit.");
+        qCWarning(KCOMPLETION_LOG) << "KComboBox::setTrapReturnKey not supported with a non-KLineEdit.";
     }
 }
 
@@ -290,8 +255,7 @@ QSize KComboBox::minimumSizeHint() const
 void KComboBox::setLineEdit(QLineEdit *edit)
 {
     Q_D(KComboBox);
-    if (!isEditable() && edit &&
-            !qstrcmp(edit->metaObject()->className(), "QLineEdit")) {
+    if (!isEditable() && edit && !qstrcmp(edit->metaObject()->className(), "QLineEdit")) {
         // uic generates code that creates a read-only KComboBox and then
         // calls combo->setEditable(true), which causes QComboBox to set up
         // a dumb QLineEdit instead of our nice KLineEdit.
@@ -322,8 +286,7 @@ void KComboBox::setLineEdit(QLineEdit *edit)
 
     // Connect the returnPressed signal for both Q[K]LineEdits'
     if (edit) {
-        connect(edit, QOverload<>::of(&QLineEdit::returnPressed),
-                this, QOverload<>::of(&KComboBox::returnPressed));
+        connect(edit, QOverload<>::of(&QLineEdit::returnPressed), this, QOverload<>::of(&KComboBox::returnPressed));
     }
 
     if (d->klineEdit) {
@@ -333,42 +296,41 @@ void KComboBox::setLineEdit(QLineEdit *edit)
         // when it is a KLineEdit!
         connect(edit, SIGNAL(destroyed()), SLOT(_k_lineEditDeleted()));
 
-        connect(d->klineEdit, QOverload<const QString&>::of(&KLineEdit::returnPressed),
-                this, QOverload<const QString&>::of(&KComboBox::returnPressed));
+        connect(d->klineEdit, &KLineEdit::returnKeyPressed, this, QOverload<const QString &>::of(&KComboBox::returnPressed));
 
-        connect(d->klineEdit, &KLineEdit::completion,
-                this, &KComboBox::completion);
+        connect(d->klineEdit, &KLineEdit::completion, this, &KComboBox::completion);
 
-        connect(d->klineEdit, &KLineEdit::substringCompletion,
-                this, &KComboBox::substringCompletion);
+        connect(d->klineEdit, &KLineEdit::substringCompletion, this, &KComboBox::substringCompletion);
 
-        connect(d->klineEdit, &KLineEdit::textRotation,
-                this, &KComboBox::textRotation);
+        connect(d->klineEdit, &KLineEdit::textRotation, this, &KComboBox::textRotation);
 
-        connect(d->klineEdit, &KLineEdit::completionModeChanged,
-                this, &KComboBox::completionModeChanged);
+        connect(d->klineEdit, &KLineEdit::completionModeChanged, this, &KComboBox::completionModeChanged);
 
-        connect(d->klineEdit, &KLineEdit::aboutToShowContextMenu,
-                this, &KComboBox::aboutToShowContextMenu);
+        connect(d->klineEdit, &KLineEdit::aboutToShowContextMenu, [this](QMenu *menu) {
+            Q_D(KComboBox);
+            d->contextMenu = menu;
+            Q_EMIT aboutToShowContextMenu(menu);
+        });
 
         // match the declaration of the deprecated signal
-#if QT_DEPRECATED_SINCE(5, 15) || QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
-        connect(d->klineEdit, &KLineEdit::completionBoxActivated,
-                this, QOverload<const QString&>::of(&QComboBox::activated));
-QT_WARNING_POP
-#endif
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-        connect(d->klineEdit, &KLineEdit::completionBoxActivated,
-                this, QOverload<const QString&>::of(&QComboBox::textActivated));
+#if QT_DEPRECATED_SINCE(5, 15)
+        QT_WARNING_PUSH
+        QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+        QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
+        connect(d->klineEdit, &KLineEdit::completionBoxActivated, this, QOverload<const QString &>::of(&QComboBox::activated));
+        QT_WARNING_POP
 #endif
+        connect(d->klineEdit, &KLineEdit::completionBoxActivated, this, &QComboBox::textActivated);
 
         d->klineEdit->setTrapReturnKey(d->trapReturnKey);
     }
 }
 
+QMenu *KComboBox::contextMenu() const
+{
+    return d_ptr->contextMenu;
+}
+
 void KComboBox::setCurrentItem(const QString &item, bool insert, int index)
 {
     int sel = -1;
@@ -407,6 +369,9 @@ void KComboBox::setEditable(bool editable)
         edit->setClearButtonEnabled(true);
         setLineEdit(edit);
     } else {
+        if (d_ptr->contextMenu) {
+            d_ptr->contextMenu->close();
+        }
         QComboBox::setEditable(editable);
     }
 }
