@@ -16,24 +16,25 @@
 #include "klineedit_p.h"
 
 #include <KAuthorized>
-#include <KSharedConfig>
 #include <KConfigGroup>
 #include <KCursor>
-#include <kcompletionbox.h>
+#include <KSharedConfig>
 #include <KStandardShortcut>
+#include <kcompletionbox.h>
 #include <lineediturldropeventfilter.h>
 
-#include <QTimer>
+#include <QActionGroup>
 #include <QApplication>
 #include <QClipboard>
 #include <QKeyEvent>
 #include <QMenu>
+#include <QTimer>
 #include <QToolTip>
 
 KLineEditPrivate::~KLineEditPrivate()
 {
-// causes a weird crash in KWord at least, so let Qt delete it for us.
-//        delete completionBox;
+    // causes a weird crash in KWord at least, so let Qt delete it for us.
+    //        delete completionBox;
 }
 
 void KLineEditPrivate::_k_textChanged(const QString &text)
@@ -43,7 +44,7 @@ void KLineEditPrivate::_k_textChanged(const QString &text)
     if (!completionRunning && (text != userText)) {
         userText = text;
 #if KCOMPLETION_BUILD_DEPRECATED_SINCE(4, 5)
-        emit q->userTextChanged(text);
+        Q_EMIT q->userTextChanged(text);
 #endif
     }
 }
@@ -57,10 +58,10 @@ void KLineEditPrivate::updateUserText(const QString &text)
         userText = text;
         q->setModified(true);
 #if KCOMPLETION_BUILD_DEPRECATED_SINCE(4, 5)
-        emit q->userTextChanged(text);
+        Q_EMIT q->userTextChanged(text);
 #endif
-        emit q->textEdited(text);
-        emit q->textChanged(text);
+        Q_EMIT q->textEdited(text);
+        Q_EMIT q->textChanged(text);
     }
 }
 
@@ -105,10 +106,12 @@ void KLineEditPrivate::init()
     KCursor::setAutoHideCursor(q, true, true);
 
     KCompletion::CompletionMode mode = q->completionMode();
-    autoSuggest = (mode == KCompletion::CompletionMan ||
-                      mode == KCompletion::CompletionPopupAuto ||
-                      mode == KCompletion::CompletionAuto);
-    q->connect(q, SIGNAL(selectionChanged()), q, SLOT(_k_restoreSelectionColors()));
+    autoSuggest = (mode == KCompletion::CompletionMan //
+                   || mode == KCompletion::CompletionPopupAuto //
+                   || mode == KCompletion::CompletionAuto);
+    q->connect(q, &KLineEdit::selectionChanged, q, [this]() {
+        _k_restoreSelectionColors();
+    });
 
     if (handleURLDrops) {
         q->installEventFilter(urlDropEventFilter);
@@ -122,18 +125,22 @@ void KLineEditPrivate::init()
         previousHighlightColor = p.color(QPalette::Normal, QPalette::Highlight);
     }
 
-    q->connect(q, SIGNAL(textChanged(QString)), q, SLOT(_k_textChanged(QString)));
+    q->connect(q, &KLineEdit::textChanged, q, [this](const QString &text) {
+        _k_textChanged(text);
+    });
 }
 
 KLineEdit::KLineEdit(const QString &string, QWidget *parent)
-    : QLineEdit(string, parent), d_ptr(new KLineEditPrivate(this))
+    : QLineEdit(string, parent)
+    , d_ptr(new KLineEditPrivate(this))
 {
     Q_D(KLineEdit);
     d->init();
 }
 
 KLineEdit::KLineEdit(QWidget *parent)
-    : QLineEdit(parent), d_ptr(new KLineEditPrivate(this))
+    : QLineEdit(parent)
+    , d_ptr(new KLineEditPrivate(this))
 {
     Q_D(KLineEdit);
     d->init();
@@ -186,25 +193,23 @@ void KLineEdit::setCompletionMode(KCompletion::CompletionMode mode)
     Q_D(KLineEdit);
     KCompletion::CompletionMode oldMode = completionMode();
 
-    if (oldMode != mode && (oldMode == KCompletion::CompletionPopup ||
-                            oldMode == KCompletion::CompletionPopupAuto) &&
-            d->completionBox && d->completionBox->isVisible()) {
+    if (oldMode != mode //
+        && (oldMode == KCompletion::CompletionPopup || oldMode == KCompletion::CompletionPopupAuto) //
+        && d->completionBox && d->completionBox->isVisible()) {
         d->completionBox->hide();
     }
 
     // If the widgets echo mode is not Normal, no completion
     // feature will be enabled even if one is requested.
     if (echoMode() != QLineEdit::Normal) {
-        mode = KCompletion::CompletionNone;    // Override the request.
+        mode = KCompletion::CompletionNone; // Override the request.
     }
 
     if (!KAuthorized::authorize(QStringLiteral("lineedit_text_completion"))) {
         mode = KCompletion::CompletionNone;
     }
 
-    if (mode == KCompletion::CompletionPopupAuto ||
-            mode == KCompletion::CompletionAuto ||
-            mode == KCompletion::CompletionMan) {
+    if (mode == KCompletion::CompletionPopupAuto || mode == KCompletion::CompletionAuto || mode == KCompletion::CompletionMan) {
         d->autoSuggest = true;
     } else {
         d->autoSuggest = false;
@@ -216,7 +221,7 @@ void KLineEdit::setCompletionMode(KCompletion::CompletionMode mode)
 void KLineEdit::setCompletionModeDisabled(KCompletion::CompletionMode mode, bool disable)
 {
     Q_D(KLineEdit);
-    d->disableCompletionMap[ mode ] = disable;
+    d->disableCompletionMap[mode] = disable;
 }
 
 void KLineEdit::setCompletedText(const QString &t, bool marked)
@@ -237,25 +242,24 @@ void KLineEdit::setCompletedText(const QString &t, bool marked)
     } else {
         setUserSelection(true);
     }
-
 }
 
 void KLineEdit::setCompletedText(const QString &text)
 {
     KCompletion::CompletionMode mode = completionMode();
-    const bool marked = (mode == KCompletion::CompletionAuto ||
-                         mode == KCompletion::CompletionMan ||
-                         mode == KCompletion::CompletionPopup ||
-                         mode == KCompletion::CompletionPopupAuto);
+    const bool marked = (mode == KCompletion::CompletionAuto //
+                         || mode == KCompletion::CompletionMan //
+                         || mode == KCompletion::CompletionPopup //
+                         || mode == KCompletion::CompletionPopupAuto);
     setCompletedText(text, marked);
 }
 
 void KLineEdit::rotateText(KCompletionBase::KeyBindingType type)
 {
     KCompletion *comp = compObj();
-    if (comp &&
-            (type == KCompletionBase::PrevCompletionMatch ||
-             type == KCompletionBase::NextCompletionMatch)) {
+    if (comp && //
+        (type == KCompletionBase::PrevCompletionMatch //
+         || type == KCompletionBase::NextCompletionMatch)) {
         QString input;
 
         if (type == KCompletionBase::PrevCompletionMatch) {
@@ -279,13 +283,12 @@ void KLineEdit::makeCompletion(const QString &text)
     KCompletion::CompletionMode mode = completionMode();
 
     if (!comp || mode == KCompletion::CompletionNone) {
-        return;    // No completion object...
+        return; // No completion object...
     }
 
     const QString match = comp->makeCompletion(text);
 
-    if (mode == KCompletion::CompletionPopup ||
-            mode == KCompletion::CompletionPopupAuto) {
+    if (mode == KCompletion::CompletionPopup || mode == KCompletion::CompletionPopupAuto) {
         if (match.isEmpty()) {
             if (d->completionBox) {
                 d->completionBox->hide();
@@ -467,10 +470,7 @@ bool KLineEditPrivate::copySqueezedText(bool copy) const
         }
         QString t = squeezedText;
         t = t.mid(start, end - start);
-        q->disconnect(QApplication::clipboard(), SIGNAL(selectionChanged()), q, nullptr);
         QApplication::clipboard()->setText(t, copy ? QClipboard::Clipboard : QClipboard::Selection);
-        q->connect(QApplication::clipboard(), SIGNAL(selectionChanged()), q,
-                SLOT(_q_clipboardChanged()));
         return true;
     }
     return false;
@@ -559,21 +559,22 @@ void KLineEdit::keyPressEvent(QKeyEvent *e)
 
     // Filter key-events if EchoMode is normal and
     // completion mode is not set to CompletionNone
-    if (echoMode() == QLineEdit::Normal &&
-            completionMode() != KCompletion::CompletionNone) {
+    if (echoMode() == QLineEdit::Normal && completionMode() != KCompletion::CompletionNone) {
         if (e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter) {
             const bool trap = (d->completionBox && d->completionBox->isVisible());
-            const bool stopEvent = (trap || (d->trapReturnKeyEvents &&
-                                             (e->modifiers() == Qt::NoButton ||
-                                              e->modifiers() == Qt::KeypadModifier)));
+            const bool stopEvent = (trap
+                                    || (d->trapReturnKeyEvents //
+                                        && (e->modifiers() == Qt::NoButton || //
+                                            e->modifiers() == Qt::KeypadModifier)));
 
             if (stopEvent) {
-                emit QLineEdit::returnPressed();
+                Q_EMIT QLineEdit::returnPressed();
                 e->accept();
             }
-
-            emit returnPressed(displayText());
-
+#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 81)
+            Q_EMIT returnPressed(displayText());
+#endif
+            Q_EMIT returnKeyPressed(displayText());
             if (trap) {
                 d->completionBox->hide();
                 deselect();
@@ -588,16 +589,17 @@ void KLineEdit::keyPressEvent(QKeyEvent *e)
 
         const KeyBindingMap keys = keyBindingMap();
         const KCompletion::CompletionMode mode = completionMode();
-        const bool noModifier = (e->modifiers() == Qt::NoButton ||
-                                 e->modifiers() == Qt::ShiftModifier ||
-                                 e->modifiers() == Qt::KeypadModifier);
+        const bool noModifier = (e->modifiers() == Qt::NoButton //
+                                 || e->modifiers() == Qt::ShiftModifier //
+                                 || e->modifiers() == Qt::KeypadModifier);
 
-        if ((mode == KCompletion::CompletionAuto ||
-             mode == KCompletion::CompletionPopupAuto ||
-             mode == KCompletion::CompletionMan) && noModifier) {
-            if (!d->userSelection && hasSelectedText() &&
-                    (e->key() == Qt::Key_Right || e->key() == Qt::Key_Left) &&
-                    e->modifiers() == Qt::NoButton) {
+        if ((mode == KCompletion::CompletionAuto //
+             || mode == KCompletion::CompletionPopupAuto //
+             || mode == KCompletion::CompletionMan) //
+            && noModifier) {
+            if (!d->userSelection && hasSelectedText() //
+                && (e->key() == Qt::Key_Right || e->key() == Qt::Key_Left) //
+                && e->modifiers() == Qt::NoButton) {
                 const QString old_txt = text();
                 d->disableRestoreSelection = true;
                 const int start = selectionStart();
@@ -610,7 +612,7 @@ void KLineEdit::keyPressEvent(QKeyEvent *e)
                 // keep cursor at cPosition
                 setSelection(old_txt.length(), cPosition - old_txt.length());
                 if (e->key() == Qt::Key_Right && cPosition > start) {
-                    //the user explicitly accepted the autocompletion
+                    // the user explicitly accepted the autocompletion
                     d->updateUserText(text());
                 }
 
@@ -629,14 +631,15 @@ void KLineEdit::keyPressEvent(QKeyEvent *e)
                 e->ignore();
                 return;
             }
-
         }
 
-        if ((mode == KCompletion::CompletionAuto ||
-             mode == KCompletion::CompletionMan) && noModifier) {
+        if ((mode == KCompletion::CompletionAuto //
+             || mode == KCompletion::CompletionMan)
+            && noModifier) {
             const QString keycode = e->text();
-            if (!keycode.isEmpty() && (keycode.unicode()->isPrint() ||
-                                       e->key() == Qt::Key_Backspace || e->key() == Qt::Key_Delete)) {
+            if (!keycode.isEmpty()
+                && (keycode.unicode()->isPrint() //
+                    || e->key() == Qt::Key_Backspace || e->key() == Qt::Key_Delete)) {
                 const bool hasUserSelection = d->userSelection;
                 const bool hadSelection = hasSelectedText();
 
@@ -690,9 +693,8 @@ void KLineEdit::keyPressEvent(QKeyEvent *e)
                 return;
             }
 
-        } else if ((mode == KCompletion::CompletionPopup ||
-                    mode == KCompletion::CompletionPopupAuto) &&
-                   noModifier && !e->text().isEmpty()) {
+        } else if ((mode == KCompletion::CompletionPopup || mode == KCompletion::CompletionPopupAuto) //
+                   && noModifier && !e->text().isEmpty()) {
             const QString old_txt = text();
             const bool hasUserSelection = d->userSelection;
             const bool hadSelection = hasSelectedText();
@@ -706,9 +708,9 @@ void KLineEdit::keyPressEvent(QKeyEvent *e)
             // autocompletion, so we want to process events at the cursor position
             // as if there was no selection. After processing the key event, we
             // can set the new autocompletion again.
-            if (hadSelection && !hasUserSelection && start > cPos &&
-                    ((!keycode.isEmpty() && keycode.unicode()->isPrint()) ||
-                     e->key() == Qt::Key_Backspace || e->key() == Qt::Key_Delete)) {
+            if (hadSelection && !hasUserSelection && start > cPos
+                && ((!keycode.isEmpty() && keycode.unicode()->isPrint()) //
+                    || e->key() == Qt::Key_Backspace || e->key() == Qt::Key_Delete)) {
                 del();
                 setCursorPosition(cPos);
                 cursorNotAtEnd = true;
@@ -721,14 +723,14 @@ void KLineEdit::keyPressEvent(QKeyEvent *e)
             d->disableRestoreSelection = false;
 
             if ((selectedLength != selectedText().length()) && !hasUserSelection) {
-                d->_k_restoreSelectionColors();    // and set userSelection to true
+                d->_k_restoreSelectionColors(); // and set userSelection to true
             }
 
             QString txt = text();
             int len = txt.length();
-            if ((txt != old_txt || txt != e->text()) && len/* && ( cursorPosition() == len || force )*/ &&
-                    ((!keycode.isEmpty() && keycode.unicode()->isPrint()) ||
-                     e->key() == Qt::Key_Backspace || e->key() == Qt::Key_Delete)) {
+            if ((txt != old_txt || txt != e->text()) && len /* && ( cursorPosition() == len || force )*/
+                && ((!keycode.isEmpty() && keycode.unicode()->isPrint()) //
+                    || e->key() == Qt::Key_Backspace || e->key() == Qt::Key_Delete)) {
                 if (e->key() == Qt::Key_Backspace) {
                     if (hadSelection && !hasUserSelection && !cursorNotAtEnd) {
                         backspace();
@@ -751,8 +753,8 @@ void KLineEdit::keyPressEvent(QKeyEvent *e)
 
                 doCompletion(txt);
 
-                if ((e->key() == Qt::Key_Backspace || e->key() == Qt::Key_Delete) &&
-                        mode == KCompletion::CompletionPopupAuto) {
+                if ((e->key() == Qt::Key_Backspace || e->key() == Qt::Key_Delete) //
+                    && mode == KCompletion::CompletionPopupAuto) {
                     d->autoSuggest = true;
                 }
 
@@ -796,7 +798,7 @@ void KLineEdit::keyPressEvent(QKeyEvent *e)
 
         if (cut.contains(key)) {
             if (emitSignals()) {
-                emit textRotation(KCompletionBase::PrevCompletionMatch);
+                Q_EMIT textRotation(KCompletionBase::PrevCompletionMatch);
             }
             if (handleSignals()) {
                 rotateText(KCompletionBase::PrevCompletionMatch);
@@ -813,7 +815,7 @@ void KLineEdit::keyPressEvent(QKeyEvent *e)
 
         if (cut.contains(key)) {
             if (emitSignals()) {
-                emit textRotation(KCompletionBase::NextCompletionMatch);
+                Q_EMIT textRotation(KCompletionBase::NextCompletionMatch);
             }
             if (handleSignals()) {
                 rotateText(KCompletionBase::NextCompletionMatch);
@@ -832,7 +834,7 @@ void KLineEdit::keyPressEvent(QKeyEvent *e)
 
             if (cut.contains(key)) {
                 if (emitSignals()) {
-                    emit substringCompletion(text());
+                    Q_EMIT substringCompletion(text());
                 }
                 if (handleSignals()) {
                     setCompletedItems(compObj()->substringCompletion(text()));
@@ -848,7 +850,7 @@ void KLineEdit::keyPressEvent(QKeyEvent *e)
     QLineEdit::keyPressEvent(e);
 
     if (selectedLength != selectedText().length()) {
-        d->_k_restoreSelectionColors();    // and set userSelection to true
+        d->_k_restoreSelectionColors(); // and set userSelection to true
     }
 }
 
@@ -857,8 +859,9 @@ void KLineEdit::mouseDoubleClickEvent(QMouseEvent *e)
     Q_D(KLineEdit);
     if (e->button() == Qt::LeftButton) {
         d->possibleTripleClick = true;
-        QTimer::singleShot(QApplication::doubleClickInterval(), this,
-                           SLOT(_k_tripleClickTimeout()));
+        QTimer::singleShot(QApplication::doubleClickInterval(), this, [d]() {
+            d->_k_tripleClickTimeout();
+        });
     }
     QLineEdit::mouseDoubleClickEvent(e);
 }
@@ -911,9 +914,19 @@ QMenu *KLineEdit::createStandardContextMenu()
     if (!isReadOnly()) {
         // FIXME: This code depends on Qt's action ordering.
         const QList<QAction *> actionList = popup->actions();
-        enum { UndoAct, RedoAct, Separator1, CutAct, CopyAct, PasteAct, DeleteAct, ClearAct,
-               Separator2, SelectAllAct, NCountActs
-             };
+        enum {
+            UndoAct,
+            RedoAct,
+            Separator1,
+            CutAct,
+            CopyAct,
+            PasteAct,
+            DeleteAct,
+            ClearAct,
+            Separator2,
+            SelectAllAct,
+            NCountActs,
+        };
         QAction *separatorAction = nullptr;
         // separator we want is right after Delete right now.
         const int idx = actionList.indexOf(actionList[DeleteAct]) + 1;
@@ -936,8 +949,9 @@ QMenu *KLineEdit::createStandardContextMenu()
     // menu item.
     if (compObj() && !isReadOnly() && KAuthorized::authorize(QStringLiteral("lineedit_text_completion"))) {
         QMenu *subMenu = popup->addMenu(QIcon::fromTheme(QStringLiteral("text-completion")), tr("Text Completion", "@title:menu"));
-        connect(subMenu, SIGNAL(triggered(QAction*)),
-                this, SLOT(_k_completionMenuActivated(QAction*)));
+        connect(subMenu, &QMenu::triggered, this, [d](QAction *action) {
+            d->_k_completionMenuActivated(action);
+        });
 
         popup->addSeparator();
 
@@ -950,7 +964,7 @@ QMenu *KLineEdit::createStandardContextMenu()
         d->popupAutoCompletionAction = ag->addAction(tr("Dropdown List && Automatic", "@item:inmenu Text Completion"));
         subMenu->addActions(ag->actions());
 
-        //subMenu->setAccel( KStandardShortcut::completion(), ShellCompletion );
+        // subMenu->setAccel( KStandardShortcut::completion(), ShellCompletion );
 
         d->shellCompletionAction->setCheckable(true);
         d->noCompletionAction->setCheckable(true);
@@ -959,12 +973,12 @@ QMenu *KLineEdit::createStandardContextMenu()
         d->shortAutoCompletionAction->setCheckable(true);
         d->popupAutoCompletionAction->setCheckable(true);
 
-        d->shellCompletionAction->setEnabled(!d->disableCompletionMap[ KCompletion::CompletionShell ]);
-        d->noCompletionAction->setEnabled(!d->disableCompletionMap[ KCompletion::CompletionNone ]);
-        d->popupCompletionAction->setEnabled(!d->disableCompletionMap[ KCompletion::CompletionPopup ]);
-        d->autoCompletionAction->setEnabled(!d->disableCompletionMap[ KCompletion::CompletionAuto ]);
-        d->shortAutoCompletionAction->setEnabled(!d->disableCompletionMap[ KCompletion::CompletionMan ]);
-        d->popupAutoCompletionAction->setEnabled(!d->disableCompletionMap[ KCompletion::CompletionPopupAuto ]);
+        d->shellCompletionAction->setEnabled(!d->disableCompletionMap[KCompletion::CompletionShell]);
+        d->noCompletionAction->setEnabled(!d->disableCompletionMap[KCompletion::CompletionNone]);
+        d->popupCompletionAction->setEnabled(!d->disableCompletionMap[KCompletion::CompletionPopup]);
+        d->autoCompletionAction->setEnabled(!d->disableCompletionMap[KCompletion::CompletionAuto]);
+        d->shortAutoCompletionAction->setEnabled(!d->disableCompletionMap[KCompletion::CompletionMan]);
+        d->popupAutoCompletionAction->setEnabled(!d->disableCompletionMap[KCompletion::CompletionPopupAuto]);
 
         const KCompletion::CompletionMode mode = completionMode();
         d->noCompletionAction->setChecked(mode == KCompletion::CompletionNone);
@@ -975,7 +989,7 @@ QMenu *KLineEdit::createStandardContextMenu()
         d->popupAutoCompletionAction->setChecked(mode == KCompletion::CompletionPopupAuto);
 
         const KCompletion::CompletionMode defaultMode = KCompletion::CompletionPopup;
-        if (mode != defaultMode && !d->disableCompletionMap[ defaultMode ]) {
+        if (mode != defaultMode && !d->disableCompletionMap[defaultMode]) {
             subMenu->addSeparator();
             d->defaultAction = subMenu->addAction(tr("Default", "@item:inmenu Text Completion"));
         }
@@ -994,20 +1008,20 @@ void KLineEdit::contextMenuEvent(QContextMenuEvent *e)
     // ### do we really need this?  Yes, Please do not remove!  This
     // allows applications to extend the popup menu without having to
     // inherit from this class! (DA)
-    emit aboutToShowContextMenu(popup);
+    Q_EMIT aboutToShowContextMenu(popup);
 
     popup->exec(e->globalPos());
     delete popup;
 }
 
-void KLineEditPrivate::_k_completionMenuActivated(QAction  *act)
+void KLineEditPrivate::_k_completionMenuActivated(QAction *act)
 {
     Q_Q(KLineEdit);
     KCompletion::CompletionMode oldMode = q->completionMode();
 
     if (act == noCompletionAction) {
         q->setCompletionMode(KCompletion::CompletionNone);
-    } else if (act ==  shellCompletionAction) {
+    } else if (act == shellCompletionAction) {
         q->setCompletionMode(KCompletion::CompletionShell);
     } else if (act == autoCompletionAction) {
         q->setCompletionMode(KCompletion::CompletionAuto);
@@ -1024,12 +1038,12 @@ void KLineEditPrivate::_k_completionMenuActivated(QAction  *act)
     }
 
     if (oldMode != q->completionMode()) {
-        if ((oldMode == KCompletion::CompletionPopup ||
-                oldMode == KCompletion::CompletionPopupAuto) &&
-                completionBox && completionBox->isVisible()) {
+        if ((oldMode == KCompletion::CompletionPopup || oldMode == KCompletion::CompletionPopupAuto) //
+            && completionBox //
+            && completionBox->isVisible()) {
             completionBox->hide();
         }
-        emit q->completionModeChanged(q->completionMode());
+        Q_EMIT q->completionModeChanged(q->completionMode());
     }
 }
 
@@ -1042,19 +1056,18 @@ bool KLineEdit::event(QEvent *ev)
         if (d->overrideShortcut(e)) {
             ev->accept();
         }
-    } else if (ev->type() == QEvent::ApplicationPaletteChange
-               || ev->type() == QEvent::PaletteChange) {
+    } else if (ev->type() == QEvent::ApplicationPaletteChange || ev->type() == QEvent::PaletteChange) {
         // Assume the widget uses the application's palette
         QPalette p = QApplication::palette();
         d->previousHighlightedTextColor = p.color(QPalette::Normal, QPalette::HighlightedText);
         d->previousHighlightColor = p.color(QPalette::Normal, QPalette::Highlight);
         setUserSelection(d->userSelection);
     } else if (ev->type() == QEvent::ChildAdded) {
-        QObject *obj = static_cast<QChildEvent*>(ev)->child();
+        QObject *obj = static_cast<QChildEvent *>(ev)->child();
         if (obj) {
             connect(obj, &QObject::objectNameChanged, this, [this, obj] {
                 if (obj->objectName() == QLatin1String("_q_qlineeditclearaction")) {
-                    QAction *action = qobject_cast<QAction*>(obj);
+                    QAction *action = qobject_cast<QAction *>(obj);
                     connect(action, &QAction::triggered, this, &KLineEdit::clearButtonClicked);
                 }
             });
@@ -1110,14 +1123,19 @@ void KLineEdit::setCompletionBox(KCompletionBox *box)
 
     d->completionBox = box;
     if (handleSignals()) {
-        connect(d->completionBox, SIGNAL(currentTextChanged(QString)),
-                SLOT(_k_completionBoxTextChanged(QString)));
-        connect(d->completionBox, &KCompletionBox::userCancelled,
-                this, &KLineEdit::userCancelled);
-        connect(d->completionBox, SIGNAL(activated(QString)),
-                SIGNAL(completionBoxActivated(QString)));
-        connect(d->completionBox, SIGNAL(activated(QString)),
-                SIGNAL(textEdited(QString)));
+        connect(d->completionBox, &KCompletionBox::currentTextChanged, this, [d](const QString &text) {
+            d->_k_completionBoxTextChanged(text);
+        });
+
+        connect(d->completionBox, &KCompletionBox::userCancelled, this, &KLineEdit::userCancelled);
+
+#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 81)
+        connect(d->completionBox, QOverload<const QString &>::of(&KCompletionBox::activated), this, &KLineEdit::completionBoxActivated);
+        connect(d->completionBox, QOverload<const QString &>::of(&KCompletionBox::activated), this, &KLineEdit::textEdited);
+#else
+        connect(d->completionBox, &KCompletionBox::textActivated, this, &KLineEdit::completionBoxActivated);
+        connect(d->completionBox, &KCompletionBox::textActivated, this, &KLineEdit::textEdited);
+#endif
     }
 }
 
@@ -1222,15 +1240,15 @@ bool KLineEditPrivate::overrideShortcut(const QKeyEvent *e)
     // but doesn't dare force as "stronger than kaction shortcuts"...
     else if (e->matches(QKeySequence::SelectAll)) {
         return true;
-    } else if (qApp->platformName() == QLatin1String("xcb") && (key == Qt::CTRL | Qt::Key_E || key == Qt::CTRL | Qt::Key_U)) {
+    } else if (qApp->platformName() == QLatin1String("xcb") && (key == (Qt::CTRL | Qt::Key_E) || key == (Qt::CTRL | Qt::Key_U))) {
         return true;
     }
 
     if (completionBox && completionBox->isVisible()) {
         const int key = e->key();
         const Qt::KeyboardModifiers modifiers = e->modifiers();
-        if ((key == Qt::Key_Backtab || key == Qt::Key_Tab) &&
-                (modifiers == Qt::NoModifier || (modifiers & Qt::ShiftModifier))) {
+        if ((key == Qt::Key_Backtab || key == Qt::Key_Tab) //
+            && (modifiers == Qt::NoModifier || (modifiers & Qt::ShiftModifier))) {
             return true;
         }
     }
@@ -1250,8 +1268,8 @@ void KLineEdit::setCompletedItems(const QStringList &items, bool autoSuggest)
         txt = text();
     }
 
-    if (!items.isEmpty() &&
-            !(items.count() == 1 && txt == items.first())) {
+    if (!items.isEmpty() //
+        && !(items.count() == 1 && txt == items.first())) {
         // create completion box if non-existent
         completionBox();
 
@@ -1312,12 +1330,10 @@ void KLineEdit::setCompletionObject(KCompletion *comp, bool handle)
 {
     KCompletion *oldComp = compObj();
     if (oldComp && handleSignals())
-        disconnect(oldComp, SIGNAL(matches(QStringList)),
-                   this, SLOT(setCompletedItems(QStringList)));
+        disconnect(oldComp, SIGNAL(matches(QStringList)), this, SLOT(setCompletedItems(QStringList)));
 
     if (comp && handle)
-        connect(comp, SIGNAL(matches(QStringList)),
-                this, SLOT(setCompletedItems(QStringList)));
+        connect(comp, SIGNAL(matches(QStringList)), this, SLOT(setCompletedItems(QStringList)));
 
     KCompletionBase::setCompletionObject(comp, handle);
 }
@@ -1325,8 +1341,8 @@ void KLineEdit::setCompletionObject(KCompletion *comp, bool handle)
 void KLineEdit::setUserSelection(bool userSelection)
 {
     Q_D(KLineEdit);
-    //if !d->userSelection && userSelection we are accepting a completion,
-    //so trigger an update
+    // if !d->userSelection && userSelection we are accepting a completion,
+    // so trigger an update
 
     if (!d->userSelection && userSelection) {
         d->updateUserText(text());
@@ -1364,7 +1380,7 @@ void KLineEditPrivate::_k_completionBoxTextChanged(const QString &text)
     if (!text.isEmpty()) {
         q->setText(text);
         q->setModified(true);
-        q->end(false);   // force cursor at end
+        q->end(false); // force cursor at end
     }
 }
 
@@ -1464,11 +1480,11 @@ void KLineEdit::doCompletion(const QString &text)
 {
     Q_D(KLineEdit);
     if (emitSignals()) {
-        emit completion(text); // emit when requested...
+        Q_EMIT completion(text); // emit when requested...
     }
     d->completionRunning = true;
     if (handleSignals()) {
-        makeCompletion(text);  // handle when requested...
+        makeCompletion(text); // handle when requested...
     }
     d->completionRunning = false;
 }
